@@ -7,4 +7,4 @@ from .publishers.confluence_sender import ConfluenceSender
 from .publishers.email_sender import EmailSender
 from .publishers.slack_sender import SlackSender
 # Utils
-from .utils.reporter_utils import upload_image
+from .utils.reporter_utils import upload_image, delete_file, zip_file
\ No newline at end of file
